==> owncloud-10.0.7.tgz: owncloud/apps/files_sharing/l10n/sl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Na tem strežniku ni omogočena možnost souporabe strežnika s strežnikom.",
    "The mountpoint name contains invalid characters." : "Ime točke priklopa vsebuje neveljavne znake.",
    "Not allowed to create a federated share with the same user server" : "Ni dovoljeno ustvariti souporabe zveznega oblaka z istim uporabnikom",
    "Invalid or untrusted SSL certificate" : "Neveljavno oziroma nepotrjeno potrdilo SSL",
    "Could not authenticate to remote share, password might be wrong" : "Ni mogoče overiti istovetnosti oddaljene mape za souporabo. Najverjetneje je uporabljeno napačno geslo.",
    "Storage not valid" : "Shramba ni veljavna",
    "Couldn't add remote share" : "Ni mogoče dodati oddaljenega mesta za souporabo",
    "Shared with you" : "V souporabi z vami",
    "Shared with others" : "V souporabi  z drugimi",
    "Shared by link" : "V souporabi prek povezave",
    "Anonymous upload" : "Brezimno pošiljanje v oblak",
    "Uploading..." : "Poteka pošiljanje ...",
    "Nothing shared with you yet" : "Datotek drugih uporabnikov še ni v souporabi",
    "Files and folders others share with you will show up here" : "Datoteke in mape, katerih souporabo z vami omogočijo drugi, bodo zbrane na tem mestu.",
    "Nothing shared yet" : "Souporabe datotek še niste omogočili",
    "Files and folders you share will show up here" : "Datoteke in mape, ki ste jih označili za souporabo z drugimi, bodo zbrane na tem mestu.",
    "No shared links" : "Ni povezav za souporabo",
    "Files and folders you share by link will show up here" : "Datoteke in mape, ki ste jih označili za souporabo prek povezave, bodo zbrane na tem mestu.",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ali želite dodati oddaljeno mesto souporabe {name} na {owner}@{remote}?",
    "Remote share" : "Oddaljeno mesto za souporabo",
    "Remote share password" : "Geslo za mesto za oddaljeno souporabo",
    "Cancel" : "Prekliči",
    "Add remote share" : "Dodaj oddaljeno mesto za souporabo",
    "You can upload into this folder" : "V to mapo je dovoljeno poslati datoteke",
    "No ownCloud installation (7 or higher) found at {remote}" : "Na mestu {remote} ni nameščenega okolja ownCloud (različice 7 ali višje)",
    "Invalid ownCloud url" : "Naveden je neveljaven naslov URL strežnika ownCloud",
    "Share" : "Souporaba",
    "No expiration date set" : "Ni nastavljenega datuma preteka.",
    "Shared by" : "V souporabi z",
    "Sharing" : "Souporaba",
    "Share API is disabled" : "API souporabe je onemogočen",
    "Wrong share ID, share doesn't exist" : "Napačen ID mesta uporabe; mesto ne obstaja!",
    "Could not delete share" : "Tega predmeta v souporabi ni mogoče izbrisati.",
    "Please specify a file or folder path" : "Določiti je treba datoteko ali pot do mape",
    "Wrong path, file/folder doesn't exist" : "Napačna pot; datoteka ali mapa ne obstaja",
    "Please specify a valid user" : "Navesti je treba veljavnega uporabnika.",
    "Group sharing is disabled by the administrator" : "Skupinska souporaba je skrbniško onemogočena",
    "Please specify a valid group" : "Navesti je treba veljavno skupino",
    "Public link sharing is disabled by the administrator" : "Souporaba prek javne povezave je skrbniško onemogočena",
    "Public upload disabled by the administrator" : "Javno pošiljanje v oblak je skrbniško onemogočeno",
    "Public upload is only possible for publicly shared folders" : "Javno pošiljanje v oblak je mogoče le za javne mape v skupni rabi.",
    "Invalid date, date format must be YYYY-MM-DD" : "Neveljaven zapis časa; biti mora v zapisu YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Omogočanje souporabe %s je spodletelo, ker ozadnji program ne dopušča souporabe vrste %s.",
    "Unknown share type" : "Neznana vrsta mesta souporabe",
    "Not a directory" : "Predmet ni mapa",
    "Could not lock path" : "Poti ni mogoče zakleniti",
    "Can't change permissions for public share links" : "Za javne povezave souporabe, spreminjanje dovoljenj ni mogoče.",
    "Wrong or no update parameter given" : "Parameter posodobitve ni podan ali pa je navedena napačna vrednost",
    "Cannot increase permissions" : "Ni mogoče povišati dovoljenj",
    "A file or folder has been <strong>shared</strong>" : "Za datoteko ali mapo je omogočena <strong>souporaba</strong>.",
    "A file or folder was shared from <strong>another server</strong>" : "Omogočena je souporaba datoteke ali mape <strong>z drugega strežnika</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "<strong>Prejeta</strong> je bila mapa ali datoteka v souporabi",
    "You received a new remote share %2$s from %1$s" : "Uporabnik %1$s vam je omogočil souporabo mape %2$s",
    "You received a new remote share from %s" : "Prejeli ste mapo za oddaljeno souporabo z %s",
    "%1$s accepted remote share %2$s" : "Uporabnik %1$s je prejel oddaljeno souporabo %2$s",
    "%1$s declined remote share %2$s" : "Uporabnik %1$s je zavrnil souporabo %2$s",
    "%1$s unshared %2$s from you" : "Uporabnik %1$s je onemogoči souporabo %2$s z vami",
    "Public shared folder %1$s was downloaded" : "Mapa v souporabi %1$s je bila prejeta.",
    "Public shared file %1$s was downloaded" : "Datoteka v souporabi %1$s je bila prejeta",
    "You shared %1$s with %2$s" : "Omogočili ste souporabo %1$s z uporabnikom %2$s",
    "%2$s shared %1$s with %3$s" : "Uporabnik %2$s je omogočil souporabo %1$s z %3$s",
    "You removed the share of %2$s for %1$s" : "Odstranili ste mapo v souporabi %2$s za %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s je odstranil souporabo %3$s za %1$s",
    "You shared %1$s with group %2$s" : "Omogočili ste souporabo %1$s s skupino %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s souporablja %1$s s skupino %3$s",
    "You removed the share of group %2$s for %1$s" : "Odstranili ste souporabo skupine %2$s za %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s je odstranil souporabo skupine %3$s za %1$s",
    "%2$s shared %1$s via link" : "%2$s je omogočil souporabo %1$s prek povezave",
    "You shared %1$s via link" : "Omogočili ste souporabo %1$s prek povezave",
    "You removed the public link for %1$s" : "Odstranili ste javno povezavo za %1$s",
    "%2$s removed the public link for %1$s" : "%2$s je odstranil javno povezavo za %1$s",
    "Your public link for %1$s expired" : "Javna povezava za %1$s je časovno potekla!",
    "The public link of %2$s for %1$s expired" : "Javna povezava %2$s za %1$s je časovno potekla!",
    "%2$s shared %1$s with you" : "Uporabnik %2$s je omogočil souporabo %1$s",
    "%2$s removed the share for %1$s" : "%2$s je odstranil souporabo za %1$s",
    "Downloaded via public link" : "Prejeto prek javne povezave",
    "Shared with %2$s" : "V souporabi z %2$s",
    "Shared with %3$s by %2$s" : "Souporaba z %3$s in %2$s",
    "Removed share for %2$s" : "Odstranjena souporaba za %2$s",
    "%2$s removed share for %3$s" : "%2$s je odstranil souporabo za %3$s",
    "Shared with group %2$s" : "V souporabi s skupino %2$s",
    "Shared with group %3$s by %2$s" : "V souporabi s skupino %3$s in %2$s",
    "Removed share of group %2$s" : "Odstranjena souporaba s skupino %2$s",
    "%2$s removed share of group %3$s" : "%2$s je odstranil povezavo za skupino %3$s",
    "Shared via link by %2$s" : "Uporabnik %2$s je omogočil souporabo prek povezave",
    "Shared via public link" : "V souporabi prek javne povezave",
    "Removed public link" : "Javno povezava je odstranjena",
    "%2$s removed public link" : "Uporabnik %2$s je odstranil javno povezavo",
    "Public link expired" : "Javna povezava je potekla",
    "Public link of %2$s expired" : "Javna povezava %2$s je potekla",
    "Shared by %2$s" : "Souporabo je omogočil uporabnik %2$s",
    "Shares" : "Souporaba",
    "This share is password-protected" : "To mesto je zaščiteno z geslom.",
    "The password is wrong. Try again." : "Geslo je napačno. Poskusite znova.",
    "Password" : "Geslo",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Name" : "Ime",
    "Share time" : "Čas souporabe",
    "Expiration date" : "Datum preteka",
    "Sorry, this link doesn’t seem to work anymore." : "Povezava očitno ni več v uporabi.",
    "Reasons might be:" : "Vzrok je lahko:",
    "the item was removed" : "predmet je odstranjen,",
    "the link expired" : "povezava je pretekla,",
    "sharing is disabled" : "souporaba je onemogočena.",
    "For more info, please ask the person who sent this link." : "Za več podrobnosti stopite v stik s pošiljateljem te povezave.",
    "%s is publicly shared" : "%s je v javni souporabi",
    "Add to your ownCloud" : "Dodaj v svoj oblak ownCloud",
    "Download" : "Prejmi",
    "Download %s" : "Prejmi %s",
    "Direct link" : "Neposredna povezava"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_sharing/l10n/sl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Na tem strežniku ni omogočena možnost souporabe strežnika s strežnikom.",
    "The mountpoint name contains invalid characters." : "Ime točke priklopa vsebuje neveljavne znake.",
    "Not allowed to create a federated share with the same user server" : "Ni dovoljeno ustvariti souporabe zveznega oblaka z istim uporabnikom",
    "Invalid or untrusted SSL certificate" : "Neveljavno oziroma nepotrjeno potrdilo SSL",
    "Could not authenticate to remote share, password might be wrong" : "Ni mogoče overiti istovetnosti oddaljene mape za souporabo. Najverjetneje je uporabljeno napačno geslo.",
    "Storage not valid" : "Shramba ni veljavna",
    "Couldn't add remote share" : "Ni mogoče dodati oddaljenega mesta za souporabo",
    "Shared with you" : "V souporabi z vami",
    "Shared with others" : "V souporabi  z drugimi",
    "Shared by link" : "V souporabi prek povezave",
    "Anonymous upload" : "Brezimno pošiljanje v oblak",
    "Uploading..." : "Poteka pošiljanje ...",
    "Nothing shared with you yet" : "Datotek drugih uporabnikov še ni v souporabi",
    "Files and folders others share with you will show up here" : "Datoteke in mape, katerih souporabo z vami omogočijo drugi, bodo zbrane na tem mestu.",
    "Nothing shared yet" : "Souporabe datotek še niste omogočili",
    "Files and folders you share will show up here" : "Datoteke in mape, ki ste jih označili za souporabo z drugimi, bodo zbrane na tem mestu.",
    "No shared links" : "Ni povezav za souporabo",
    "Files and folders you share by link will show up here" : "Datoteke in mape, ki ste jih označili za souporabo prek povezave, bodo zbrane na tem mestu.",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ali želite dodati oddaljeno mesto souporabe {name} na {owner}@{remote}?",
    "Remote share" : "Oddaljeno mesto za souporabo",
    "Remote share password" : "Geslo za mesto za oddaljeno souporabo",
    "Cancel" : "Prekliči",
    "Add remote share" : "Dodaj oddaljeno mesto za souporabo",
    "You can upload into this folder" : "V to mapo je dovoljeno poslati datoteke",
    "No ownCloud installation (7 or higher) found at {remote}" : "Na mestu {remote} ni nameščenega okolja ownCloud (različice 7 ali višje)",
    "Invalid ownCloud url" : "Naveden je neveljaven naslov URL strežnika ownCloud",
    "Share" : "Souporaba",
    "No expiration date set" : "Ni nastavljenega datuma preteka.",
    "Shared by" : "V souporabi z",
    "Sharing" : "Souporaba",
    "Share API is disabled" : "API souporabe je onemogočen",
    "Wrong share ID, share doesn't exist" : "Napačen ID mesta uporabe; mesto ne obstaja!",
    "Could not delete share" : "Tega predmeta v souporabi ni mogoče izbrisati.",
    "Please specify a file or folder path" : "Določiti je treba datoteko ali pot do mape",
    "Wrong path, file/folder doesn't exist" : "Napačna pot; datoteka ali mapa ne obstaja",
    "Please specify a valid user" : "Navesti je treba veljavnega uporabnika.",
    "Group sharing is disabled by the administrator" : "Skupinska souporaba je skrbniško onemogočena",
    "Please specify a valid group" : "Navesti je treba veljavno skupino",
    "Public link sharing is disabled by the administrator" : "Souporaba prek javne povezave je skrbniško onemogočena",
    "Public upload disabled by the administrator" : "Javno pošiljanje v oblak je skrbniško onemogočeno",
    "Public upload is only possible for publicly shared folders" : "Javno pošiljanje v oblak je mogoče le za javne mape v skupni rabi.",
    "Invalid date, date format must be YYYY-MM-DD" : "Neveljaven zapis časa; biti mora v zapisu YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Omogočanje souporabe %s je spodletelo, ker ozadnji program ne dopušča souporabe vrste %s.",
    "Unknown share type" : "Neznana vrsta mesta souporabe",
    "Not a directory" : "Predmet ni mapa",
    "Could not lock path" : "Poti ni mogoče zakleniti",
    "Can't change permissions for public share links" : "Za javne povezave souporabe, spreminjanje dovoljenj ni mogoče.",
    "Wrong or no update parameter given" : "Parameter posodobitve ni podan ali pa je navedena napačna vrednost",
    "Cannot increase permissions" : "Ni mogoče povišati dovoljenj",
    "A file or folder has been <strong>shared</strong>" : "Za datoteko ali mapo je omogočena <strong>souporaba</strong>.",
    "A file or folder was shared from <strong>another server</strong>" : "Omogočena je souporaba datoteke ali mape <strong>z drugega strežnika</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "<strong>Prejeta</strong> je bila mapa ali datoteka v souporabi",
    "You received a new remote share %2$s from %1$s" : "Uporabnik %1$s vam je omogočil souporabo mape %2$s",
    "You received a new remote share from %s" : "Prejeli ste mapo za oddaljeno souporabo z %s",
    "%1$s accepted remote share %2$s" : "Uporabnik %1$s je prejel oddaljeno souporabo %2$s",
    "%1$s declined remote share %2$s" : "Uporabnik %1$s je zavrnil souporabo %2$s",
    "%1$s unshared %2$s from you" : "Uporabnik %1$s je onemogoči souporabo %2$s z vami",
    "Public shared folder %1$s was downloaded" : "Mapa v souporabi %1$s je bila prejeta.",
    "Public shared file %1$s was downloaded" : "Datoteka v souporabi %1$s je bila prejeta",
    "You shared %1$s with %2$s" : "Omogočili ste souporabo %1$s z uporabnikom %2$s",
    "%2$s shared %1$s with %3$s" : "Uporabnik %2$s je omogočil souporabo %1$s z %3$s",
    "You removed the share of %2$s for %1$s" : "Odstranili ste mapo v souporabi %2$s za %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s je odstranil souporabo %3$s za %1$s",
    "You shared %1$s with group %2$s" : "Omogočili ste souporabo %1$s s skupino %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s souporablja %1$s s skupino %3$s",
    "You removed the share of group %2$s for %1$s" : "Odstranili ste souporabo skupine %2$s za %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s je odstranil souporabo skupine %3$s za %1$s",
    "%2$s shared %1$s via link" : "%2$s je omogočil souporabo %1$s prek povezave",
    "You shared %1$s via link" : "Omogočili ste souporabo %1$s prek povezave",
    "You removed the public link for %1$s" : "Odstranili ste javno povezavo za %1$s",
    "%2$s removed the public link for %1$s" : "%2$s je odstranil javno povezavo za %1$s",
    "Your public link for %1$s expired" : "Javna povezava za %1$s je časovno potekla!",
    "The public link of %2$s for %1$s expired" : "Javna povezava %2$s za %1$s je časovno potekla!",
    "%2$s shared %1$s with you" : "Uporabnik %2$s je omogočil souporabo %1$s",
    "%2$s removed the share for %1$s" : "%2$s je odstranil souporabo za %1$s",
    "Downloaded via public link" : "Prejeto prek javne povezave",
    "Shared with %2$s" : "V souporabi z %2$s",
    "Shared with %3$s by %2$s" : "Souporaba z %3$s in %2$s",
    "Removed share for %2$s" : "Odstranjena souporaba za %2$s",
    "%2$s removed share for %3$s" : "%2$s je odstranil souporabo za %3$s",
    "Shared with group %2$s" : "V souporabi s skupino %2$s",
    "Shared with group %3$s by %2$s" : "V souporabi s skupino %3$s in %2$s",
    "Removed share of group %2$s" : "Odstranjena souporaba s skupino %2$s",
    "%2$s removed share of group %3$s" : "%2$s je odstranil povezavo za skupino %3$s",
    "Shared via link by %2$s" : "Uporabnik %2$s je omogočil souporabo prek povezave",
    "Shared via public link" : "V souporabi prek javne povezave",
    "Removed public link" : "Javno povezava je odstranjena",
    "%2$s removed public link" : "Uporabnik %2$s je odstranil javno povezavo",
    "Public link expired" : "Javna povezava je potekla",
    "Public link of %2$s expired" : "Javna povezava %2$s je potekla",
    "Shared by %2$s" : "Souporabo je omogočil uporabnik %2$s",
    "Shares" : "Souporaba",
    "This share is password-protected" : "To mesto je zaščiteno z geslom.",
    "The password is wrong. Try again." : "Geslo je napačno. Poskusite znova.",
    "Password" : "Geslo",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Name" : "Ime",
    "Share time" : "Čas souporabe",
    "Expiration date" : "Datum preteka",
    "Sorry, this link doesn’t seem to work anymore." : "Povezava očitno ni več v uporabi.",
    "Reasons might be:" : "Vzrok je lahko:",
    "the item was removed" : "predmet je odstranjen,",
    "the link expired" : "povezava je pretekla,",
    "sharing is disabled" : "souporaba je onemogočena.",
    "For more info, please ask the person who sent this link." : "Za več podrobnosti stopite v stik s pošiljateljem te povezave.",
    "%s is publicly shared" : "%s je v javni souporabi",
    "Add to your ownCloud" : "Dodaj v svoj oblak ownCloud",
    "Download" : "Prejmi",
    "Download %s" : "Prejmi %s",
    "Direct link" : "Neposredna povezava",
    "Uploaded files" : "Datoteke, poslane v oblak",
    "Click to select files or use drag & drop to upload" : "Kliknite za izbor datotek oziroma uporabite možnost povleci in spusti za pošiljanje v oblak ...",
    "Cannot remove all permissions" : "Vseh dovoljenj ni mogoče odstraniti",
    "Pending" : "V čakanju ...",
    "Accept" : "Sprejmi",
    "Decline" : "Zavrni",
    "Declined" : "Zavrnjeno"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
